| Title: | Open datasets in a View tab and external softwares |
|---|---|
| Description: | RStudio addin to quickly inspect data in a View tab or open them with default CSV/text editor softwares. |
| Authors: | Francois Keck [aut, cre] |
| Maintainer: | Francois Keck <[email protected]> |
| License: | GPL-3 |
| Version: | 0.2.1 |
| Built: | 2026-05-09 08:52:11 UTC |
| Source: | https://github.com/fkeck/quickview |
Open data with default CSV/text editor
qv_open()qv_open()
Open working directory with the file manager
qv_wd()qv_wd()